|Travis|_ |CircleCI|_ |ReadTheDocs|_ |Codecov|_

.. |Travis| image:: https://travis-ci.org/aglingael/dl8.5.svg?branch=master
.. _Travis: https://travis-ci.org/aglingael/dl8.5

.. |CircleCI| image:: https://circleci.com/gh/aglingael/dl8.5/tree/master.svg?style=svg
.. _CircleCI: https://circleci.com/gh/aglingael/dl8.5/

.. |ReadTheDocs| image:: https://readthedocs.org/projects/dl85/badge/?version=latest
.. _ReadTheDocs: https://dl85.readthedocs.io/en/latest/?badge=latest

.. |Codecov| image:: https://codecov.io/gh/aglingael/dl8.5/branch/master/graph/badge.svg
.. _Codecov: https://codecov.io/gh/aglingael/dl8.5

This project is used to infer binary optimal decision trees classifier.
It is a scikit-learn compatible classifier which can be used with any scikit-learn functions.
As any scikit-learn classifier, you have to use methods "fit" and "predict".

